@@ -2,7 +2,7 @@
  *  SPDX-FileCopyrightText: 2019 David Redondo <kde@david-redondo.de>
  *  SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  *
- *  SPDX-License-Identifier: GPL-2.0-or-later
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "Config.h"
@@ -11,6 +11,10 @@
 #include "SpectacleCore.h"
 #include "SpectacleDBusAdapter.h"
 
+#ifdef KIMAGEANNOTATOR_CAN_LOAD_TRANSLATIONS
+#include <kImageAnnotator/KImageAnnotator.h>
+#endif
+
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDBusConnection>
@@ -71,6 +75,10 @@ int main(int argc, char **argv)
     // For some reason this does not work properly if behind an if
     KDBusService service(KDBusService::Unique, &lCore);
 
+#ifdef KIMAGEANNOTATOR_CAN_LOAD_TRANSLATIONS
+    kImageAnnotator::loadTranslations();
+#endif
+
     // Delay initialisation after we now we are in the single instance or new-instance was passed, to avoid doing it each time spectacle executable is called
     lCore.init();
 
